<?php

namespace EventPortal\AuthPassword\Tests\Feature;

use EventPortal\AuthPassword\EmailAction;
use EventPortal\AuthPassword\Tests\TestCase;
use EventPortal\AuthPassword\Tests\User;

class HandleEmailActionTest extends TestCase
{
    /** @test **/
    public function guest_without_password_is_redirect_to_create_one()
    {
        User::create([
            'email' => 'someone@example.com',
            'password' => null,
            'password_token' => 'TOKEN',
            'password_created_at' => null,
        ]);

        $action = EmailAction::make('http://google.com')
            ->token('TOKEN')
            ->get();

        $this
            ->get($action)
            ->assertRedirect(route('create-password.index', [
                'token' => 'TOKEN',
            ]));
    }

    /** @test **/
    public function logged_in_user_is_redirect_to_intended()
    {
        $user = User::create([
            'email' => 'someone@example.com',
            'password' => 'password',
            'password_token' => null,
            'password_created_at' => now(),
        ]);

        $action = EmailAction::make('http://google.com')->get();

        $this
            ->actingAs($user)
            ->get($action)
            ->assertRedirect('http://google.com');
    }

    /** @test **/
    public function guest_with_invalid_token_is_redirect_to_login()
    {
        User::create([
            'email' => 'someone@example.com',
            'password' => null,
            'password_token' => 'TOKEN',
            'password_created_at' => null,
        ]);

        $action = EmailAction::make('http://google.com')->token('wrong_token')->get();

        $this
            ->get($action)
            ->assertRedirect(route('login.index'));
    }
}
